package com.dongqiudi.dqd_plugin;

import android.util.Log;

import com.alibaba.fastjson.JSON;
import com.dongqiudi.dqd_plugin.http.CallBack;
import com.dongqiudi.dqd_plugin.http.HttUtils;
import com.lzy.okgo.model.HttpHeaders;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * DqdPlugin
 */
public class DqdPlugin implements MethodCallHandler {
    private static final String TAG = "DqdPlugin";

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "dqd_plugin");
        channel.setMethodCallHandler(new DqdPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        Log.d(TAG, "onMethodCall method " + call.method);
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case PluginConfig.REQUEST_TEAM_FAV:
                doRequest(call, result);
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    private void doRequest(final MethodCall call, final Result result) {
        String header = call.argument("header");
        Log.d(TAG, "header " + header);
        Map maps = (Map) JSON.parse(header);
        HttpHeaders httpHeaders;
        if (maps != null && !maps.isEmpty()) {
            httpHeaders = new HttpHeaders();
            for (Object map : maps.entrySet()) {
                Log.d(TAG, ((Map.Entry) map).getKey() + "     " + ((Map.Entry) map).getValue());
                httpHeaders.put(((Map.Entry) map).getKey().toString(), ((Map.Entry) map).getValue().toString());
            }
        }
        HttUtils.get((String) call.argument("url"), new CallBack() {
            @Override
            public void success(String jsonStr) {
                switch (call.method) {
                    case PluginConfig.REQUEST_TEAM_FAV:
                        result.success(jsonStr);
                        break;
                    default:
                        result.notImplemented();
                        break;
                }
            }

            @Override
            public void fail(String errInfo) {
                switch (call.method) {
                    case PluginConfig.REQUEST_TEAM_FAV:
                        result.error(errInfo, null, null);
                        break;
                    default:
                        result.notImplemented();
                        break;
                }

            }
        }, TAG, (HttpHeaders) call.argument("header"), null);
    }
}